==> benchling-api-client-2.0.21.tar.gz: benchling-api-client-2.0.21/benchling_api_client/v2/alpha/api/analyses/patch_analysis_data.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.analysis_step_data import AnalysisStepData
from ...models.analysis_step_data_update import AnalysisStepDataUpdate
from ...models.forbidden_error import ForbiddenError
from ...models.not_found_error import NotFoundError
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Dict[str, Any]:
    url = "{}/analysis-step-data/{analysis_step_data_id}".format(
        client.base_url, analysis_step_data_id=analysis_step_data_id
    )

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    if response.status_code == 200:
        response_200 = AnalysisStepData.from_dict(response.json())

        return response_200
    if response.status_code == 403:
        response_403 = ForbiddenError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = NotFoundError.from_dict(response.json())

        return response_404
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Response[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    )

    response = client.httpx_client.patch(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Optional[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    """ Patch a piece of analysis data """

    return sync_detailed(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Response[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.patch(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Optional[Union[AnalysisStepData, ForbiddenError, NotFoundError]]:
    """ Patch a piece of analysis data """

    return (
        await asyncio_detailed(
            client=client,
            analysis_step_data_id=analysis_step_data_id,
            json_body=json_body,
        )
    ).parsed

==> benchling-api-client-2.0.30.tar.gz: benchling-api-client-2.0.30/benchling_api_client/v2/alpha/api/analyses/patch_analysis_data.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.analysis_step_data import AnalysisStepData
from ...models.analysis_step_data_update import AnalysisStepDataUpdate
from ...models.bad_request_error import BadRequestError
from ...models.forbidden_error import ForbiddenError
from ...models.not_found_error import NotFoundError
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Dict[str, Any]:
    url = "{}/analysis-step-data/{analysis_step_data_id}".format(
        client.base_url, analysis_step_data_id=analysis_step_data_id
    )

    headers: Dict[str, Any] = client.httpx_client.headers
    headers.update(client.get_headers())

    cookies: Dict[str, Any] = client.httpx_client.cookies
    cookies.update(client.get_cookies())

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    if response.status_code == 200:
        response_200 = AnalysisStepData.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = BadRequestError.from_dict(response.json())

        return response_400
    if response.status_code == 403:
        response_403 = ForbiddenError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = NotFoundError.from_dict(response.json())

        return response_404
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Response[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    )

    response = client.httpx_client.patch(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Optional[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    """ Patch a piece of analysis data that is associated with a third-party analysis step """

    return sync_detailed(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Response[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    kwargs = _get_kwargs(
        client=client,
        analysis_step_data_id=analysis_step_data_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.patch(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    analysis_step_data_id: str,
    json_body: AnalysisStepDataUpdate,
) -> Optional[Union[AnalysisStepData, BadRequestError, ForbiddenError, NotFoundError]]:
    """ Patch a piece of analysis data that is associated with a third-party analysis step """

    return (
        await asyncio_detailed(
            client=client,
            analysis_step_data_id=analysis_step_data_id,
            json_body=json_body,
        )
    ).parsed
